searchData={"items":[{"type":"module","title":"Xeo","doc":"Elegantly generate seo and social tags for your Phoenix app.\n\nWhen used, this module will inject the `seo/1` and other macros in your module,\nwhich you can then use to elegantly define the tags for your pages.","ref":"Xeo.html"},{"type":"module","title":"Usage - Xeo","doc":"defmodule MySeo\n      use Xeo\n      # OR\n      use Xeo, opts\n    end","ref":"Xeo.html#module-usage"},{"type":"module","title":"Use Options - Xeo","doc":"* `:router` (optional):\n    Your app's router name which will be used to verify the routes\n    if the `:warn` options is set to `true`\n    (the defaults to `YourAppsName.Router`)\n\n  * `:warn` (optional):\n    A boolean flag which specifies whether to emit compile time warnings\n    if the seo macro was not defined for some path. (defaults to `true`)\n\n  * `:pad` (optional):\n    An option for formatting the final HTML tags. This option\n    specifies how much leading space to add prior to each meta tag\n    (defaults to `4` spaces)","ref":"Xeo.html#module-use-options"},{"type":"module","title":"Example - Xeo","doc":"defmodule MyApp.Seo do\n        use Xeo\n        # use Xeo, warn: false, pad: 2\n\n        seo \"/\" do\n          title \"Some page\"\n          description \"Some SEO description\"\n\n          og_title \"Welcome\"\n          og_image \"https://example.com/image.jpg\"\n          og_description \"Some SEO description\"\n          ...\n        end\n\n        seo \"/contact\" do\n          title: \"Contact Us\"\n          description \"Our contact page is awesome\"\n\n          og_title \"Contact us\"\n          og_image fn -> Routes.static_path(Endpoint, \"/images/image.jpg\") end\n          og_description \"Our contact page\"\n          ...\n\n          twitter_title: \"Contact us\"\n        end\n    end","ref":"Xeo.html#module-example"},{"type":"function","title":"Xeo.check_routes/2","doc":"Step over each `GET` route and and check if an seo function was\ndefined for it, and if not, optionally show a compilation warning.","ref":"Xeo.html#check_routes/2"},{"type":"macro","title":"Xeo.seo/2","doc":"A macro for generating a function (named `seo_for_path`)\nthat will match on `conn.request_path` and will generate the corresponding meta tags.","ref":"Xeo.html#seo/2"},{"type":"module","title":"Xeo.Page","doc":"A structure to hold the html data for a given page.","ref":"Xeo.Page.html"},{"type":"module","title":"Page Fields - Xeo.Page","doc":"","ref":"Xeo.Page.html#module-page-fields"},{"type":"module","title":"Basic Tags - Xeo.Page","doc":"- :title\n- :description\n- :canonical","ref":"Xeo.Page.html#module-basic-tags"},{"type":"module","title":"Open Graph Tags - Xeo.Page","doc":"- :og_type\n- :og_title\n- :og_description\n- :og_image\n- :og_site_name\n- :og_url","ref":"Xeo.Page.html#module-open-graph-tags"},{"type":"module","title":"Twitter Cards - Xeo.Page","doc":"- :twitter_card\n- :twitter_site\n- :twitter_title\n- :twitter_description\n- :twitter_url\n- :twitter_image","ref":"Xeo.Page.html#module-twitter-cards"},{"type":"function","title":"Xeo.Page.html/2","doc":"Generate html tags from the given struct","ref":"Xeo.Page.html#html/2"},{"type":"type","title":"Xeo.Page.t/0","doc":"","ref":"Xeo.Page.html#t:t/0"},{"type":"type","title":"Xeo.Page.tag_content/0","doc":"The content for a given tag","ref":"Xeo.Page.html#t:tag_content/0"},{"type":"extras","title":"Xeo","doc":"# Xeo\n\nEasily and elegantly generate various seo and social sharing html tags\nfor your [Phoenix](https://www.phoenixframework.org/)-powered web pages.\n\n```elixir\n  seo \"/my-page\" do\n    og_title \"My Awesome Page\"\n    og_image \"/images/some-image.jpg\"\n  end\n```\n\n#### Tags Macro Reference\n\nHere are the macros automatically injected, which you can use inside the block supplied\nto the `seo` macro:\n\n- `title`\n- `description`\n- `canonical`\n- `og_type`\n- `og_title`\n- `og_description`\n- `og_image`\n- `og_site_name`\n- `og_url`\n- `twitter_card`\n- `twitter_site`\n- `twitter_title`\n- `twitter_description`\n- `twitter_url`\n- `twitter_image`","ref":"readme.html"},{"type":"extras","title":"Installation - Xeo","doc":"Add the `xeo` package to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:xeo, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Xeo","doc":"The typical flow involes (1) using the `Xeo` module, (2) invoking the `Xeo.seo/2` macro\nto define the tags for each page based on its path, and (3) injecting\nthe `MyModule.tags(@conn)` function in the root template, inside the ` ... ` tag.","ref":"readme.html#usage"},{"type":"extras","title":"Example - Xeo","doc":"```elixir\ndefmodule MyApp.Seo do\n  use Xeo\n  # Alternatively, `use Xeo, warn: false, pad: 2`\n\n  seo \"/awesome\" do\n    og_title \"My Awesome Page\"\n    og_image \"/images/awesome.jpg\"\n    ...\n  end\n\n  seo \"/another-page\" ...\nend\n```\n\nUpdate your `root.html.heex`:\n\n```html\n \n   \n    ...\n    <%= MyApp.Seo.tags(@conn) %>\n   \n```\n\nNow let's check if it works:\n\n```sh\n$ curl localhost:4000/awesome\n...\n \n   \n   \n...\n```\n\nIn the example above we used the `og_title` and `og_image` macros to define the open graph tags for our `/contact` page.\n\nDo note that the above module will contain a `tags/1` function, which accepts\na phoenix connection and returns the tags associated with the page identified\nby the connection's path.","ref":"readme.html#example"},{"type":"extras","title":"Use Options - Xeo","doc":"When invoking `use Xeo` you can supply additional options:\n\n- `:warn` (boolean) - show compilation time warnings (default true)\n- `:pad` (integer) - how much whitespace padding to use for html tags (default 4)","ref":"readme.html#use-options"},{"type":"extras","title":"Formatting - Xeo","doc":"For elegant formatting when using the supplied macros,\nyou can import `:xeo` in your project's formatter file:\n\n\n```elixir\n# .formatter.exs\n[\n  ...\n  import_deps: [:xeo],\n  ...\n]\n```","ref":"readme.html#formatting"},{"type":"extras","title":"License - Xeo","doc":"Copyright (c) 2024 Tony Walker – MIT License","ref":"readme.html#license"},{"type":"extras","title":"Xeo Changelog","doc":"# Xeo Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1 (April 22, 2024) - Xeo Changelog","doc":"- Initial release","ref":"changelog.html#v0-1-april-22-2024"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}